==> apache-dolphinscheduler-3.2.0-src.tar.gz: apache-dolphinscheduler-3.2.0-src/dolphinscheduler-ui/src/locales/zh_CN/datasource.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  datasource: '数据源',
  create_datasource: '创建源',
  choose_datasource_type: '选择源类型',
  select: '更改',
  search_input_tips: '请输入关键字',
  datasource_name: '源名称',
  datasource_name_tips: '请输入数据源名称',
  datawarehouse: '数据仓库',
  datawarehouse_tips: '请输入数据仓库',
  datasource_user_name: '所属用户',
  datasource_type: '源类型',
  datasource_parameter: '参数',
  description: '描述',
  description_tips: '请输入描述',
  create_time: '创建时间',
  update_time: '更新时间',
  operation: '操作',
  click_to_view: '点击查看',
  delete: '删除',
  confirm: '确定',
  delete_confirm: '删除？',
  cancel: '取消',
  create: '创建',
  edit: '编辑',
  success: '成功',
  test_connect: '测试连接',
  ip: 'IP主机名',
  ip_tips: '请输入IP主机名',
  port: '端口',
  port_tips: '请输入端口',
  database_name: '数据库名',
  database_name_tips: '请输入数据库名',
  oracle_connect_type: '服务名或SID',
  oracle_connect_type_tips: '请选择服务名或SID',
  oracle_service_name: '服务名',
  oracle_sid: 'SID',
  compatible_mode: '兼容模式',
  compatible_mode_tips: '请输入兼容模式',
  jdbc_connect_parameters: 'jdbc连接参数',
  principal_tips: '请输入Principal',
  krb5_conf_tips: '请输入kerberos认证参数 java.security.krb5.conf',
  keytab_username_tips: '请输入kerberos认证参数 login.user.keytab.username',
  keytab_path_tips: '请输入kerberos认证参数 login.user.keytab.path',
  format_tips: '请输入格式为',
  connection_parameter: '连接参数',
  user_name: '用户名',
  user_name_tips: '请输入用户名',
  user_password: '密码',
  user_password_tips: '请输入密码',
  aws_region: 'AwsRegion',
  aws_region_tips: '请输入AwsRegion',
  validation: '验证',
  mode_tips: '请选择验证模式',
  jdbc_format_tips: 'jdbc连接参数不是一个正确的JSON格式',
  database_username: '数据库用户名',
  database_password: '数据库密码',
  Azure_AD_username: 'Azure AD用户名',
  Azure_AD_password: 'Azure AD密码',
  MSIClientId: 'MSI ClientId',
  clientId: 'ClientId',
  clientSecret: 'ClientSecret',
  OAuth_token_endpoint: 'OAuth 2.0 token endpoint',
  endpoint_tips: '请输入OAuth',
  AccessKeyID: 'AccessKeyID',
  AccessKeyID_tips: '请输入AccessKeyID',
  SecretAccessKey: 'SecretAccessKey',
  SecretAccessKey_tips: '请输入SecretAccessKey',
  dbUser: 'DbUser',
  dbUser_tips: '请输入DbUser'
}

==> apache-dolphinscheduler-3.3.2-src.tar.gz: apache-dolphinscheduler-3.3.2-src/dolphinscheduler-ui/src/locales/zh_CN/datasource.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  datasource: '数据源',
  create_datasource: '创建源',
  choose_datasource_type: '选择源类型',
  select: '更改',
  search_input_tips: '请输入关键字',
  datasource_name: '源名称',
  datasource_name_tips: '请输入数据源名称',
  datawarehouse: '数据仓库',
  datawarehouse_tips: '请输入数据仓库',
  datasource_user_name: '所属用户',
  datasource_type: '源类型',
  datasource_parameter: '参数',
  description: '描述',
  description_tips: '请输入描述',
  create_time: '创建时间',
  update_time: '更新时间',
  operation: '操作',
  click_to_view: '点击查看',
  delete: '删除',
  confirm: '确定',
  delete_confirm: '删除？',
  cancel: '取消',
  create: '创建',
  edit: '编辑',
  success: '成功',
  test_connect: '测试连接',
  ip: 'IP主机名',
  ip_tips: '请输入IP主机名',
  port: '端口',
  port_tips: '请输入端口',
  database_name: '数据库名',
  database_name_tips: '请输入数据库名',
  oracle_connect_type: '服务名或SID',
  oracle_connect_type_tips: '请选择服务名或SID',
  oracle_service_name: '服务名',
  oracle_sid: 'SID',
  compatible_mode: '兼容模式',
  compatible_mode_tips: '请输入兼容模式',
  jdbc_connect_parameters: 'jdbc连接参数',
  principal_tips: '请输入Principal',
  krb5_conf_tips: '请输入kerberos认证参数 java.security.krb5.conf',
  keytab_username_tips: '请输入kerberos认证参数 login.user.keytab.username',
  keytab_path_tips: '请输入kerberos认证参数 login.user.keytab.path',
  format_tips: '请输入格式为',
  connection_parameter: '连接参数',
  user_name: '用户名',
  user_name_tips: '请输入用户名',
  user_password: '密码',
  user_password_tips: '请输入密码',
  aws_region: 'AwsRegion',
  aws_region_tips: '请输入AwsRegion',
  aws_access_key: 'AwsAccessKey',
  aws_access_key_tips: '请输入AwsAccessKey',
  aws_secret_access_key: 'AwsSecretAccessKey',
  aws_secret_access_key_tips: '请输入AwsSecretAccessKey',
  validation: '验证',
  mode_tips: '请选择验证模式',
  jdbc_format_tips: 'jdbc连接参数不是一个正确的JSON格式',
  database_username: '数据库用户名',
  database_password: '数据库密码',
  Azure_AD_username: 'Azure AD用户名',
  Azure_AD_password: 'Azure AD密码',
  MSIClientId: 'MSI ClientId',
  clientId: 'ClientId',
  clientSecret: 'ClientSecret',
  OAuth_token_endpoint: 'OAuth 2.0 token endpoint',
  OAuth_token_endpoint_tips: '请输入OAuth',
  AccessKeyID: 'AccessKeyID',
  AccessKeyID_tips: '请输入AccessKeyID',
  SecretAccessKey: 'SecretAccessKey',
  SecretAccessKey_tips: '请输入SecretAccessKey',
  dbUser: 'DbUser',
  dbUser_tips: '请输入DbUser',
  zeppelin_rest_endpoint: 'zeppelinRestEndpoint',
  zeppelin_rest_endpoint_tips: '请输入zeppelin server的rest endpoint',
  kubeConfig: 'kubeConfig',
  kubeConfig_tips: '请输入KubeConfig',
  namespace: 'namespace',
  namespace_tips: '请输入namespace',
  access_key_id: 'Access Key Id',
  access_key_id_tips: '请输入access key id',
  access_key_secret: 'Access Key Secret',
  access_key_secret_tips: '请输入access key secret',
  region_id: 'Region Id',
  region_id_tips: '请输入Region Id',
  endpoint: 'endpoint',
  endpoint_tips: '请输入endpoint'
}
